summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/enum.h
diff options
context:
space:
mode:
authordolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-10-16 21:42:51 +0000
committerdolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-10-16 21:42:51 +0000
commitfcd2f73d85997682a9c89c897348ae8e32432589 (patch)
tree96faec16d93756f84ac6b64aaa67e6f7befd5cec /crawl-ref/source/enum.h
parent66e21b71a9d7d1e2569caa2c63d25e3b935fd2c0 (diff)
downloadcrawl-ref-fcd2f73d85997682a9c89c897348ae8e32432589.tar.gz
crawl-ref-fcd2f73d85997682a9c89c897348ae8e32432589.zip
Replace Yred's "Control Undead" power with "Enslave Soul", as proposed
on crawl-ref-discuss. git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@7263 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/enum.h')
-rw-r--r--crawl-ref/source/enum.h57
1 files changed, 31 insertions, 26 deletions
diff --git a/crawl-ref/source/enum.h b/crawl-ref/source/enum.h
index 6856219604..941155f61b 100644
--- a/crawl-ref/source/enum.h
+++ b/crawl-ref/source/enum.h
@@ -66,7 +66,7 @@ enum ability_type
ABIL_YRED_RECALL_UNDEAD,
ABIL_YRED_ANIMATE_DEAD,
ABIL_YRED_DRAIN_LIFE,
- ABIL_YRED_CONTROL_UNDEAD, // 144
+ ABIL_YRED_ENSLAVE_SOUL, // 144
// 160 - reserved for Vehumet
ABIL_OKAWARU_MIGHT = 170, // 170
// Okawaru no longer heals (JPEG)
@@ -217,6 +217,7 @@ enum beam_type // beam[].flavour
BEAM_BANISH,
BEAM_DEGENERATE,
BEAM_ENSLAVE_UNDEAD,
+ BEAM_ENSLAVE_SOUL,
BEAM_PAIN,
BEAM_DISPEL_UNDEAD,
BEAM_DISINTEGRATION,
@@ -1978,31 +1979,34 @@ enum mon_flight_type
// These are now saved in an unsigned long in the monsters struct.
enum monster_flag_type
{
- MF_CREATED_FRIENDLY = 0x01, // no benefit from killing
- MF_BATTY = 0x02, // flutters like a bat
- MF_JUST_SUMMONED = 0x04, // monster skips next available action
- MF_TAKING_STAIRS = 0x08, // is following player through stairs
-
- MF_INTERESTING = 0x10, // Player finds monster interesting
- MF_SEEN = 0x20, // Player has already seen monster
- MF_DIVINE_PROTECTION = 0x40, // Monster has divine protection.
-
- MF_KNOWN_MIMIC = 0x80, // Mimic that has taken a swing at the PC,
- // or that the player has inspected with ?
- MF_BANISHED = 0x100, // Monster that has been banished.
- MF_HARD_RESET = 0x200, // Summoned, should not drop gear on reset
- MF_WAS_NEUTRAL = 0x400, // mirror to CREATED_FRIENDLY for neutrals
- MF_ATT_CHANGE_ATTEMPT = 0x800, // Saw player and attitude changed (or
- // not); currently used for holy beings
- // (good god worshippers -> neutral)
- // and orcs (Beogh worshippers -> friendly)
- MF_WAS_IN_VIEW = 0x1000, // Was in view during previous turn
- MF_BAND_MEMBER = 0x2000, // Created as a member of a band
- MF_GOT_HALF_XP = 0x4000, // Player already got half xp value earlier
- MF_HONORARY_UNDEAD = 0x8000 // Consider this monster to have MH_UNDEAD
- // holiness, regardless of its actual type;
- // currently used for abominations created
- // via Twisted Resurrection
+ MF_CREATED_FRIENDLY = 0x01, // no benefit from killing
+ MF_BATTY = 0x02, // flutters like a bat
+ MF_JUST_SUMMONED = 0x04, // monster skips next available action
+ MF_TAKING_STAIRS = 0x08, // is following player through stairs
+
+ MF_INTERESTING = 0x10, // Player finds monster interesting
+ MF_SEEN = 0x20, // Player has already seen monster
+ MF_DIVINE_PROTECTION = 0x40, // Monster has divine protection.
+
+ MF_KNOWN_MIMIC = 0x80, // Mimic that has taken a swing at the PC,
+ // or that the player has inspected with ?
+ MF_BANISHED = 0x100, // Monster that has been banished.
+ MF_HARD_RESET = 0x200, // Summoned, should not drop gear on reset
+ MF_WAS_NEUTRAL = 0x400, // mirror to CREATED_FRIENDLY for neutrals
+ MF_ATT_CHANGE_ATTEMPT = 0x800, // Saw player and attitude changed (or
+ // not); currently used for holy beings
+ // (good god worshippers -> neutral)
+ // and orcs (Beogh worshippers -> friendly)
+ MF_WAS_IN_VIEW = 0x1000, // Was in view during previous turn
+ MF_BAND_MEMBER = 0x2000, // Created as a member of a band
+ MF_GOT_HALF_XP = 0x4000, // Player already got half xp value earlier
+ MF_HONORARY_UNDEAD = 0x8000, // Consider this monster to have MH_UNDEAD
+ // holiness, regardless of its actual type;
+ // currently used for abominations created
+ // via Twisted Resurrection
+ MF_ENSLAVED_SOUL = 0x10000 // An undead monster soul enslaved by
+ // Yredelemnul's power, or the natural
+ // monster from whom the soul is taken
};
// Adding slots breaks saves. YHBW.
@@ -2962,6 +2966,7 @@ enum zap_type
ZAP_BREATHE_STICKY_FLAME,
ZAP_BREATHE_LIGHTNING,
ZAP_PETRIFY,
+ ZAP_ENSLAVE_SOUL,
ZAP_HELLFROST,
NUM_ZAPS
};